@@ -4,9 +4,6 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: wings_filter.cpp,v 1.13 2010/07/29 19:32:33 cvs Exp $
-//      $Date: 2010/07/29 19:32:33 $
-//
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
 //   published by the Free Software Foundation.
@@ -34,17 +31,17 @@
 #include <rdconfig.h>
 #include <rdcmd_switch.h>
 #include <rdcut.h>
+#include <rdescape_string.h>
 #include <wings_filter.h>
 
-
 //
 // Global Variables
 //
 RDConfig *rdconfig;
 
 
-MainObject::MainObject(QObject *parent,const char *name)
-  : QObject(parent,name)
+MainObject::MainObject(QObject *parent)
+  : QObject(parent)
 {
   //
   // Read Command Options
@@ -65,6 +62,7 @@ MainObject::MainObject(QObject *parent,const char *name)
 
   rdconfig=new RDConfig(RD_CONF_FILE);
   rdconfig->load();
+  rdconfig->setModuleName("wings_filter");
 
   //
   // Open Database
@@ -86,17 +84,17 @@ MainObject::MainObject(QObject *parent,const char *name)
     exit(1);
   }
 
-  //
-  // RIPCD Connection
-  //
-  filter_ripc=new RDRipc("");
-  filter_ripc->connectHost("localhost",RIPCD_TCP_PORT,rdconfig->password());
-
   //
   // Station Configuration
   //
   filter_rdstation=new RDStation(rdconfig->stationName());
 
+  //
+  // RIPCD Connection
+  //
+  filter_ripc=new RDRipc(filter_rdstation,rdconfig,this);
+  filter_ripc->connectHost("localhost",RIPCD_TCP_PORT,rdconfig->password());
+
   //
   // Read Arguments
   //
@@ -249,20 +247,19 @@ bool MainObject::ImportCut(RDGroup *group,struct WingsRecord *rec,
 			rec->filename,rec->extension);
   q=new RDSqlQuery(sql);
   delete q;
-  sql=QString().sprintf("insert into CUTS set CUT_NAME=\"%06u_001\",\
-                         CART_NUMBER=%u,DESCRIPTION=\"%s\",\
-                         ORIGIN_DATETIME=\"%s\",ORIGIN_NAME=\"%s\",\
-                         CODING_FORMAT=%d,SAMPLE_RATE=%u,CHANNELS=%d,\
-                         BIT_RATE=%d,LENGTH=%u,START_POINT=0,\
-                         END_POINT=%d",
-			cartnum,cartnum,(const char *)rec->title,
-			(const char *)QDateTime::currentDateTime().
-			toString("yyyy-MM-dd hh:mm:ss"),
-			(const char *)rdconfig->stationName(),format,
-			wavefile->getSamplesPerSec(),
-			wavefile->getChannels(),wavefile->getHeadBitRate(),
-			wavefile->getExtTimeLength(),
-			wavefile->getExtTimeLength());
+  RDCut::create(cartnum,1);
+  sql=QString("update CUTS set ")+
+    "DESCRIPTION=\""+RDEscapeString(rec->title)+"\","+
+    "ORIGIN_DATETIME=now(),"+
+    "ORIGIN_NAME=\""+RDEscapeString(rdconfig->stationName())+"\","+
+    QString().sprintf("CODING_FORMAT=%d,",format)+
+    QString().sprintf("SAMPLE_RATE=%u,",wavefile->getSamplesPerSec())+
+    QString().sprintf("CHANNELS=%d,",wavefile->getChannels())+
+    QString().sprintf("BIT_RATE=%d,",wavefile->getHeadBitRate())+
+    QString().sprintf("LENGTH=%u,",wavefile->getExtTimeLength())+
+    "START_POINT=0,"+
+    QString().sprintf("END_POINT=%d where ",wavefile->getExtTimeLength())+
+    "CUT_NAME=\""+RDCut::cutName(cartnum,1)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 
@@ -324,6 +321,6 @@ void MainObject::TrimSpaces(char *str)
 int main(int argc,char *argv[])
 {
   QApplication a(argc,argv,false);
-  new MainObject(NULL,"main");
+  new MainObject(NULL);
   return a.exec();
 }
