@@ -2,7 +2,7 @@
 //
 // Export a Rivendell Report to RadioTraffic.com
 //
-//   (C) Copyright 2002-2005,2009,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2005,2009,2016-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,7 +29,8 @@
 #include <rdreport.h>
 
 
-bool RDReport::ExportRadioTraffic(const QDate &startdate,const QDate &enddate,
+bool RDReport::ExportRadioTraffic(const QString &filename,
+				  const QDate &startdate,const QDate &enddate,
 				  const QString &mixtable)
 {
   QString sql;
@@ -37,14 +38,6 @@ bool RDReport::ExportRadioTraffic(const QDate &startdate,const QDate &enddate,
   FILE *f;
   QString air_fmt;
 
-#ifdef WIN32
-  QString filename=
-    RDDateDecode(exportPath(RDReport::Windows),startdate,serviceName());
-#else
-  QString filename=
-    RDDateDecode(exportPath(RDReport::Linux),startdate,serviceName());
-#endif
-
   QFile file(filename);
   if((f=fopen((const char *)filename,"wb"))==NULL) {
     report_error_code=RDReport::ErrorCantOpen;
