@@ -515,6 +515,22 @@
         <source>template host</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished">Záběr</translation>
+    </message>
+    <message>
+        <source>Log already exists!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>No such service!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -1881,11 +1897,11 @@ Bitte Kofiguration prüfen und erneut versuchen.</translation>
     <name>RDListLogs</name>
     <message>
         <source>Select Log - User: </source>
-        <translation>Vybrat zápis - uživatel:</translation>
+        <translation type="obsolete">Vybrat zápis - uživatel:</translation>
     </message>
     <message>
         <source>Select Log</source>
-        <translation>Vybrat zápis</translation>
+        <translation type="unfinished">Vybrat zápis</translation>
     </message>
     <message>
         <source>NAME</source>
@@ -1927,6 +1943,29 @@ Bitte Kofiguration prüfen und erneut versuchen.</translation>
         <translation>Spuštěné služby</translation>
     </message>
 </context>
+<context>
+    <name>RDLogFilter</name>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filter</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished">Smazat</translation>
+    </message>
+    <message>
+        <source>Show Only Recent Logs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ALL</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDLogLine</name>
     <message>
