@@ -465,6 +465,46 @@
         <source>cart</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Host already exists!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>host already exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>service already exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>template service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>does not exist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>template host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already exists!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No such service!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -1675,14 +1715,6 @@ Do you want to overwrite it?</source>
 </context>
 <context>
     <name>RDListLogs</name>
-    <message>
-        <source>Select Log - User: </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Select Log</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>NAME</source>
         <translation type="unfinished"></translation>
@@ -1703,6 +1735,10 @@ Do you want to overwrite it?</source>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Select Log</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDListSelector</name>
@@ -1723,6 +1759,29 @@ Do you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>RDLogFilter</name>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filter</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished">Effacer</translation>
+    </message>
+    <message>
+        <source>Show Only Recent Logs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ALL</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDLogLine</name>
     <message>
@@ -1800,6 +1859,93 @@ please try again!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>RDRenderer</name>
+    <message>
+        <source>no such cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>no such cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Using temporary file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pass 2 of 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Writing output file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pass 1 of 1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pass 1 of 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Importing cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>first-time event not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>last-time event not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>STOP</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FAIL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NO AUDIO AVAILABLE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SKIP</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>--- end of log ---</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unable to open output file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>log render halted at line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>due to STOP</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>at line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>failed to play (NO AUDIO AVAILABLE)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendered log is too long!</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDSoundPanel</name>
     <message>
