@@ -511,6 +511,22 @@
         <source>template host</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished">Klypp</translation>
+    </message>
+    <message>
+        <source>Log already exists!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>No such service!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -1872,14 +1888,6 @@ Sjekk eksportoppsettet ditt og prøv att.</translation>
 </context>
 <context>
     <name>RDListLogs</name>
-    <message>
-        <source>Select Log - User: </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Select Log</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>NAME</source>
         <translation type="unfinished"></translation>
@@ -1900,6 +1908,14 @@ Sjekk eksportoppsettet ditt og prøv att.</translation>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Select Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ALL</source>
+        <translation type="obsolete">ALLE</translation>
+    </message>
 </context>
 <context>
     <name>RDListSelector</name>
@@ -1920,6 +1936,29 @@ Sjekk eksportoppsettet ditt og prøv att.</translation>
         <translation>Aktive tenester</translation>
     </message>
 </context>
+<context>
+    <name>RDLogFilter</name>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filter</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished">Tøm</translation>
+    </message>
+    <message>
+        <source>Show Only Recent Logs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ALL</source>
+        <translation type="unfinished">ALLE</translation>
+    </message>
+</context>
 <context>
     <name>RDLogLine</name>
     <message>
