@@ -2,9 +2,7 @@
 //
 // Test for the existence of audio in a Rivendell Audio Cut.
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdaudio_exists.cpp,v 1.6 2007-09-22 20:44:14 dmills Exp $
+//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,8 +26,8 @@
 
 bool RDAudioExists(QString cutname)
 {
-  QFile file;
-  QString pathname = RDCut::pathName(cutname); 
-  file.setName(pathname);
-  return file.exists();
+  RDCut *cut=new RDCut(cutname);
+  bool ret=cut->exists()&&(cut->length()>0);
+  delete cut;
+  return ret;
 }
