@@ -2,9 +2,7 @@
 //
 // Export an Audio File using the RdXport Web Service
 //
-//   (C) Copyright 2010 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdaudioexport.cpp,v 1.8 2011/12/23 23:07:00 cvs Exp $
+//   (C) Copyright 2010,2016-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -53,11 +51,12 @@ int ExportProgressCallback(void *clientp,double dltotal,double dlnow,
 }
 
 
-RDAudioExport::RDAudioExport(RDStation *station,
-			     QObject *parent,const char *name)
-  : QObject(parent,name)
+RDAudioExport::RDAudioExport(RDStation *station,RDConfig *config,
+			     QObject *parent)
+  : QObject(parent)
 {
   conv_station=station;
+  conv_config=config;
   conv_cart_number=0;
   conv_cut_number=0;
   conv_start_point=-1;
@@ -68,24 +67,48 @@ RDAudioExport::RDAudioExport(RDStation *station,
 }
 
 
+unsigned RDAudioExport::cartNumber() const
+{
+  return conv_cart_number;
+}
+
+
 void RDAudioExport::setCartNumber(unsigned cartnum)
 {
   conv_cart_number=cartnum;
 }
 
 
+unsigned RDAudioExport::cutNumber() const
+{
+  return conv_cut_number;
+}
+
+
 void RDAudioExport::setCutNumber(unsigned cutnum)
 {
   conv_cut_number=cutnum;
 }
 
 
+QString RDAudioExport::destinationFile() const
+{
+  return conv_dst_filename;
+}
+
+
 void RDAudioExport::setDestinationFile(const QString &filename)
 {
   conv_dst_filename=filename;
 }
 
 
+RDSettings *RDAudioExport::destinationSettings() const
+{
+  return conv_settings;
+}
+
+
 void RDAudioExport::setDestinationSettings(RDSettings *settings)
 {
   conv_settings=settings;
@@ -147,11 +170,13 @@ RDAudioExport::ErrorCode RDAudioExport::runExport(const QString &username,
   // otherwise some versions of LibCurl will throw a 'bad/illegal format' 
   // error.
   //
-  strncpy(url,conv_station->webServiceUrl(),1024);
+  strncpy(url,conv_station->webServiceUrl(conv_config),1024);
   curl_easy_setopt(curl,CURLOPT_URL,url);
   curl_easy_setopt(curl,CURLOPT_WRITEDATA,f);
   curl_easy_setopt(curl,CURLOPT_POST,1);
   curl_easy_setopt(curl,CURLOPT_POSTFIELDS,(const char *)post);
+  curl_easy_setopt(curl,CURLOPT_USERAGENT,
+		   (const char *)conv_config->userAgent());
   curl_easy_setopt(curl,CURLOPT_TIMEOUT,RD_CURL_TIMEOUT);
   curl_easy_setopt(curl,CURLOPT_PROGRESSFUNCTION,ExportProgressCallback);
   curl_easy_setopt(curl,CURLOPT_PROGRESSDATA,this);
@@ -175,6 +200,7 @@ RDAudioExport::ErrorCode RDAudioExport::runExport(const QString &username,
   case CURLE_OUT_OF_MEMORY:
   case CURLE_OPERATION_TIMEDOUT:
   case CURLE_HTTP_POST_ERROR:
+  default:
     curl_easy_cleanup(curl);
     return RDAudioExport::ErrorInternal;
 
