@@ -2,9 +2,7 @@
 //
 // Abstract an RDCatch Configuration.
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdcatch_conf.cpp,v 1.2 2007/09/14 14:06:24 fredg Exp $
+//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,16 +18,17 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <rddb.h>
 #include <rdconf.h>
 #include <rdcatch_conf.h>
-
+#include <rdescape_string.h>
 
 //
 // Global Classes
 //
 RDCatchConf::RDCatchConf(const QString &station)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   air_station=station;
@@ -37,16 +36,17 @@ RDCatchConf::RDCatchConf(const QString &station)
   sql=QString().
     sprintf("select ID from RDCATCH where STATION=\"%s\"",
 			(const char *)air_station);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(!q->first()) {
     delete q;
     sql=QString().
       sprintf("insert into RDCATCH set STATION=\"%s\"",
 			  (const char *)air_station);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
+    delete q;
+  } else {
     delete q;
   }
-  delete q;
 }
 
 
@@ -70,14 +70,14 @@ void RDCatchConf::setErrorRml(const QString &str) const
 
 void RDCatchConf::SetRow(const QString &param,const QString &value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().
     sprintf("UPDATE RDCATCH SET %s=\"%s\" WHERE STATION=\"%s\"",
-			(const char *)param,
-			(const char *)value,
-			(const char *)air_station);
-  q=new QSqlQuery(sql);
+	    (const char *)param,
+	    (const char *)RDEscapeString(value),
+	    (const char *)RDEscapeString(air_station));
+  q=new RDSqlQuery(sql);
   delete q;
 }
