@@ -2,9 +2,7 @@
 //
 // Abstract a Rivendell Log Manager Event
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdevent_line.h,v 1.18 2010/07/29 19:32:33 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,16 +18,15 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#ifndef RDEVENT_LINE_H
+#define RDEVENT_LINE_H
+
 #include <qsqldatabase.h>
 #include <qdatetime.h>
 
 #include <rdlog_event.h>
 #include <rdlog_line.h>
 
-
-#ifndef RDEVENT_LINE_H
-#define RDEVENT_LINE_H
-
 class RDEventLine
 {
  public:
@@ -82,7 +79,7 @@ class RDEventLine
   void setLength(int msecs);
   void clear();
   bool load();
-  bool save();
+  bool save(RDConfig *config);
   bool generateLog(QString logname,const QString &svcname,
 		   QString *errors, unsigned artistsep,QString clockname);
   bool linkLog(RDLogEvent *e,int next_id,const QString &svcname,
