@@ -2,9 +2,7 @@
 //
 // Get an Agreggate Tuning Hours (ATH) Figure.
 //
-//   (C) Copyright 2006 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdget_ath.h,v 1.2 2007/02/14 21:48:41 fredg Exp $
+//   (C) Copyright 2006,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -26,12 +24,11 @@
 #include <qdialog.h>
 #include <qlineedit.h>
 
-
 class RDGetAth : public QDialog
 {
   Q_OBJECT
   public:
-   RDGetAth(double *ath,QWidget *parent=0,const char *name=0);
+   RDGetAth(double *ath,QWidget *parent=0);
    ~RDGetAth();
    QSize sizeHint() const;
    QSizePolicy sizePolicy() const;
