@@ -2,9 +2,7 @@
 //
 // Add a Rivendell Matrix
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: add_matrix.h,v 1.6 2010/07/29 19:32:34 cvs Exp $
+//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,12 +28,11 @@
 
 #include <rduser.h>
 
-
 class AddMatrix : public QDialog
 {
  Q_OBJECT
  public:
-  AddMatrix(QString station,QWidget *parent=0,const char *name=0);
+  AddMatrix(QString station,QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
