@@ -53,7 +53,9 @@ class EditDropbox : public QDialog
   void schedcodesData();
   void normalizationToggledData(bool state);
   void autotrimToggledData(bool state);
+  void segueToggledData(bool state);
   void createDatesToggledData(bool state);
+  void resetData();
   void okData();
   void cancelData();
   
@@ -65,6 +67,8 @@ class EditDropbox : public QDialog
   QPushButton *box_schedcodes_button;
   QCheckBox *box_delete_cuts_box;
   QLabel *box_delete_cuts_label;
+  QCheckBox *box_force_to_mono_box;
+  QLabel *box_force_to_mono_label;
   QLineEdit *box_metadata_pattern_edit;
   QLineEdit *box_user_defined_edit;
   QLineEdit *box_log_path_edit;
@@ -90,6 +94,13 @@ class EditDropbox : public QDialog
   QSpinBox *box_create_enddate_offset_spin;
   QLabel *box_create_enddate_label;
   QLabel *box_create_enddate_unit;
+  QCheckBox *box_segue_box;
+  QSpinBox *box_segue_level_spin;
+  QLabel *box_segue_level_label;
+  QLabel *box_segue_level_unit;
+  QSpinBox *box_segue_length_spin;
+  QLabel *box_segue_length_label;
+  QLabel *box_segue_length_unit;
   RDSchedCodesDialog *box_schedcodes_dialog;
   QStringList box_schedcodes;
 };
