@@ -2,9 +2,7 @@
 //
 // Edit an RDLibrry Configuration
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_rdlibrary.h,v 1.19.6.1 2014/01/09 01:03:55 cvs Exp $
+//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -39,8 +37,7 @@ class EditRDLibrary : public QDialog
 {
   Q_OBJECT
  public:
-  EditRDLibrary(RDStation *station,RDStation *cae_station,
-		QWidget *parent=0,const char *name=0);
+  EditRDLibrary(RDStation *station,RDStation *cae_station,QWidget *parent=0);
   ~EditRDLibrary();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -66,6 +63,7 @@ class EditRDLibrary : public QDialog
   QTimeEdit *lib_maxlength_time;
   QLineEdit *lib_ripdev_edit;
   QComboBox *lib_paranoia_box;
+  QComboBox *lib_isrc_box;
   QSpinBox *lib_riplevel_spin;
   QLineEdit *lib_cddb_edit;
   QComboBox *lib_editor_box;
