@@ -2,9 +2,7 @@
 //
 // List and Generate RDCatch Reports
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: list_reports.h,v 1.5 2010/07/29 19:32:36 cvs Exp $
+//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,13 +27,11 @@
 
 #include <rdsvc.h>
 
-
 class ListReports : public QDialog
 {
  Q_OBJECT
  public:
- ListReports(bool active_only,bool today_only,int dow,
-	     QWidget *parent=0,const char *name=0);
+ ListReports(bool active_only,bool today_only,int dow,QWidget *parent=0);
  ~ListReports();
  QSize sizeHint() const;
  QSizePolicy sizePolicy() const;
