@@ -2,7 +2,7 @@
 //
 // The Rivendell Netcatcher Daemon
 //
-//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -41,26 +41,27 @@
 #include <qsignalmapper.h>
 #include <qsessionmanager.h>
 
-#include <rddb.h>
-#include <rdconf.h>
-#include <rdhash.h>
-#include <rdurl.h>
-#include <rdwavefile.h>
-#include <rdcut.h>
+#include <dbversion.h>
 #include <rdcatchd_socket.h>
 #include <rdcatchd.h>
-#include <rdrecording.h>
-#include <rdttyout.h>
-#include <rdmixer.h>
 #include <rdcheck_daemons.h>
-#include <rddebug.h>
+#include <rdconf.h>
+#include <rdcut.h>
 #include <rddatedecode.h>
+#include <rddb.h>
+#include <rddebug.h>
 #include <rdescape_string.h>
-#include <rdpodcast.h>
-#include <rdsettings.h>
+#include <rdhash.h>
 #include <rdlibrary_conf.h>
+#include <rdmixer.h>
 #include <rdpaths.h>
-#include <dbversion.h>
+#include <rdpodcast.h>
+#include <rdrecording.h>
+#include <rdsettings.h>
+#include <rdtempdirectory.h>
+#include <rdttyout.h>
+#include <rdurl.h>
+#include <rdwavefile.h>
 
 RDConfig *catch_config;
 
@@ -133,6 +134,7 @@ MainObject::MainObject(QObject *parent)
   //
   catch_config=new RDConfig();
   catch_config->load();
+  catch_config->setModuleName("rdcatchd");
 
   //
   // Read Command Options
@@ -189,7 +191,7 @@ MainObject::MainObject(QObject *parent)
   //
   // Calculate Temporary Directory
   //
-  catch_temp_dir=RDTempDir();
+  catch_temp_dir=RDTempDirectory::basePath();
 
   //
   // Macro Event Handling
@@ -253,10 +255,15 @@ MainObject::MainObject(QObject *parent)
   catch_xload_timer=new QTimer(this);
   connect(catch_xload_timer,SIGNAL(timeout()),this,SLOT(updateXloadsData()));
 
+  //
+  // Station Configuration
+  //
+  catch_rdstation=new RDStation(catch_config->stationName());
+
   //
   // RIPCD Connection
   //
-  catch_ripc=new RDRipc(catch_config->stationName());
+  catch_ripc=new RDRipc(catch_rdstation,catch_config,this);
   catch_ripc->connectHost("localhost",RIPCD_TCP_PORT,catch_config->password());
   connect(catch_ripc,SIGNAL(rmlReceived(RDMacro *)),
 	  this,SLOT(rmlReceivedData(RDMacro *)));
@@ -268,11 +275,6 @@ MainObject::MainObject(QObject *parent)
   //
   catch_system=new RDSystem();
 
-  //
-  // Station Configuration
-  //
-  catch_rdstation=new RDStation(catch_config->stationName());
-
   //
   // CAE Connection
   //
@@ -635,208 +637,211 @@ void MainObject::engineData(int id)
   // Load Deck Parameters
   //
   switch(catch_events[event].type()) {
-      case RDRecording::Recording:
-	if(!RDCut::exists(catch_events[event].cutName())) {
-	  WriteExitCode(event,RDRecording::NoCut);
-	  BroadcastCommand(QString().
-			   sprintf("RE %d %d %d!",
-				catch_events[event].channel(),
-				catch_record_deck_status[catch_events[event].
-							 channel()-1],
-				catch_events[event].id()));
-	  LogLine(RDConfig::LogWarning,QString().
-		  sprintf("record aborted: no such cut: %s, id: %d",
-			  (const char *)catch_events[event].cutName(),
-			  catch_events[event].id()));
-	  return;
-	}
-	catch_record_card[catch_events[event].channel()-1]=-1;
-	catch_record_stream[catch_events[event].channel()-1]=-1;
-	sql=QString().sprintf("select CARD_NUMBER,PORT_NUMBER,\
-                         SWITCH_STATION,SWITCH_MATRIX,SWITCH_OUTPUT,\
-                         SWITCH_DELAY from DECKS \
+  case RDRecording::Recording:
+    if(!RDCut::exists(catch_events[event].cutName())) {
+      WriteExitCode(event,RDRecording::NoCut);
+      BroadcastCommand(QString().
+		       sprintf("RE %d %d %d!",
+			       catch_events[event].channel(),
+			       catch_record_deck_status[catch_events[event].
+							channel()-1],
+			       catch_events[event].id()));
+      LogLine(RDConfig::LogWarning,QString().
+	      sprintf("record aborted: no such cut: %s, id: %d",
+		      (const char *)catch_events[event].cutName(),
+		      catch_events[event].id()));
+      return;
+    }
+    catch_record_card[catch_events[event].channel()-1]=-1;
+    catch_record_stream[catch_events[event].channel()-1]=-1;
+    sql=QString().sprintf("select CARD_NUMBER,PORT_NUMBER,\
+                         SWITCH_STATION,SWITCH_MATRIX,SWITCH_OUTPUT,	\
+                         SWITCH_DELAY from DECKS			\
                          where (STATION_NAME=\"%s\")&&(CHANNEL=%d)",
-			      (const char *)catch_config->stationName(),
-			      catch_events[event].channel());
-	q=new RDSqlQuery(sql);
-	if(q->first()) {
-	  catch_record_card[catch_events[event].channel()-1]=
-	    q->value(0).toInt();
-	  catch_record_stream[catch_events[event].channel()-1]=
-	    q->value(1).toInt();
-	  if(q->value(2).toString()==QString("[none]")) {
-	    catch_swaddress[catch_events[event].channel()-1]=QHostAddress();
-	  }
-	  else {
-	    rdstation=new RDStation(q->value(2).toString());
-	    catch_swaddress[catch_events[event].channel()-1]=
-	      rdstation->address();
-	    delete rdstation;
-	  }
-	  catch_swmatrix[catch_events[event].channel()-1]=q->value(3).toInt();
-	  catch_swoutput[catch_events[event].channel()-1]=q->value(4).toInt();
-	  catch_swdelay[catch_events[event].channel()-1]=q->value(5).toInt();
-	}
-	else {
-	  LogLine(RDConfig::LogNotice,QString().
-		  sprintf("id %d specified non-existent record deck, ignored",
-			  catch_events[event].id()));
-	  delete q;
-	  return;
-	}
-	delete q;
+			  (const char *)catch_config->stationName(),
+			  catch_events[event].channel());
+    q=new RDSqlQuery(sql);
+    if(q->first()) {
+      catch_record_card[catch_events[event].channel()-1]=
+	q->value(0).toInt();
+      catch_record_stream[catch_events[event].channel()-1]=
+	q->value(1).toInt();
+      if(q->value(2).toString()==QString("[none]")) {
+	catch_swaddress[catch_events[event].channel()-1]=QHostAddress();
+      }
+      else {
+	rdstation=new RDStation(q->value(2).toString());
+	catch_swaddress[catch_events[event].channel()-1]=
+	  rdstation->address();
+	delete rdstation;
+      }
+      catch_swmatrix[catch_events[event].channel()-1]=q->value(3).toInt();
+      catch_swoutput[catch_events[event].channel()-1]=q->value(4).toInt();
+      catch_swdelay[catch_events[event].channel()-1]=q->value(5).toInt();
+    }
+    else {
+      LogLine(RDConfig::LogNotice,QString().
+	      sprintf("id %d specified non-existent record deck, ignored",
+		      catch_events[event].id()));
+      delete q;
+      return;
+    }
+    delete q;
+    
+    sql=QString("delete from CUT_EVENTS where ")+
+      "CUT_NAME=\""+catch_events[event].cutName()+"\"";
+    q=new RDSqlQuery(sql);
+    delete q;
 
-	sql=QString("delete from CUT_EVENTS where ")+
-	  "CUT_NAME=\""+catch_events[event].cutName()+"\"";
-	q=new RDSqlQuery(sql);
-	delete q;
+    switch(catch_events[event].startType()) {
+    case RDRecording::HardStart:
+      StartRecording(event);
+      break;
 
-	switch(catch_events[event].startType()) {
-	    case RDRecording::HardStart:
-	      StartRecording(event);
-	      break;
+    case RDRecording::GpiStart:
+      catch_events[event].gpiStartTimer()->
+	start(catch_events[event].startLength()-
+	      (QTime().msecsTo(current_time)-
+	       QTime().msecsTo(catch_events[event].startTime())),true);
+      catch_record_deck_status[catch_events[event].channel()-1]=
+	RDDeck::Waiting;
+      catch_record_id[catch_events[event].channel()-1]=
+	catch_events[event].id();
+      catch_events[event].setStatus(RDDeck::Waiting);
+      WriteExitCode(event,RDRecording::Waiting);
+      BroadcastCommand(QString().sprintf("RE %d %d %d!",
+		       catch_events[event].channel(),
+		       catch_record_deck_status[catch_events[event].
+						channel()-1],
+					 catch_events[event].id()));
+      LogLine(RDConfig::LogNotice,QString().
+	      sprintf("gpi start window opens: event: %d, gpi: %d:%d",
+		      id,catch_events[event].startMatrix(),
+		      catch_events[event].startLine()));
+      break;
+    }
+    break;
 
-	    case RDRecording::GpiStart:
-	      catch_events[event].gpiStartTimer()->
-		start(catch_events[event].startLength()-
-		      (QTime().msecsTo(current_time)-
-		       QTime().msecsTo(catch_events[event].startTime())),true);
-	      catch_record_deck_status[catch_events[event].channel()-1]=
-		RDDeck::Waiting;
-	      catch_record_id[catch_events[event].channel()-1]=
-		catch_events[event].id();
-	      catch_events[event].setStatus(RDDeck::Waiting);
-	      WriteExitCode(event,RDRecording::Waiting);
-	      BroadcastCommand(QString().sprintf("RE %d %d %d!",
-			 catch_events[event].channel(),
-			 catch_record_deck_status[catch_events[event].
-			 channel()-1],
-                         catch_events[event].id()));
-	      LogLine(RDConfig::LogNotice,QString().
-		      sprintf("gpi start window opens: event: %d, gpi: %d:%d",
-			      id,catch_events[event].startMatrix(),
-			      catch_events[event].startLine()));
-	      break;
-	}
-	break;
-
-      case RDRecording::Playout:
-	if(!RDCut::exists(catch_events[event].cutName())) {
-	  WriteExitCode(event,RDRecording::NoCut);
-	  BroadcastCommand(QString().
-			   sprintf("RE %d %d %d!",
-				catch_events[event].channel(),
-				catch_playout_deck_status[catch_events[event].
-							  channel()-129],
-				   catch_events[event].id()));
-	  LogLine(RDConfig::LogNotice,QString().
-		  sprintf("playout aborted: no such cut: %s, id: %d",
-			  (const char *)catch_events[event].cutName(),
-			  catch_events[event].id()));
-	  return;
-	}
-	catch_playout_card[catch_events[event].channel()-129]=-1;
-	catch_playout_stream[catch_events[event].channel()-129]=-1;
-	sql=QString().sprintf("select CARD_NUMBER,PORT_NUMBER,PORT_NUMBER \
+  case RDRecording::Playout:
+    if(!RDCut::exists(catch_events[event].cutName())) {
+      WriteExitCode(event,RDRecording::NoCut);
+      BroadcastCommand(QString().
+		       sprintf("RE %d %d %d!",
+			       catch_events[event].channel(),
+			       catch_playout_deck_status[catch_events[event].
+							 channel()-129],
+			       catch_events[event].id()));
+      LogLine(RDConfig::LogNotice,QString().
+	      sprintf("playout aborted: no such cut: %s, id: %d",
+		      (const char *)catch_events[event].cutName(),
+		      catch_events[event].id()));
+      return;
+    }
+    catch_playout_card[catch_events[event].channel()-129]=-1;
+    catch_playout_stream[catch_events[event].channel()-129]=-1;
+    sql=QString().sprintf("select CARD_NUMBER,PORT_NUMBER,PORT_NUMBER \
                          from DECKS where (STATION_NAME=\"%s\")&&(CHANNEL=%d)",
-			      (const char *)catch_config->stationName(),
-			      catch_events[event].channel());
-	q=new RDSqlQuery(sql);
-	if(q->first()) {
-	  catch_playout_id[catch_events[event].channel()-129]=id;
-	  catch_playout_card[catch_events[event].channel()-129]=
-	    q->value(0).toInt();
-	  catch_playout_stream[catch_events[event].channel()-129]=
-	    q->value(1).toInt();
-	  catch_playout_port[catch_events[event].channel()-129]=
-	    q->value(2).toInt();
-	}
-	else {
-	  LogLine(RDConfig::LogDebug,QString().
-		  sprintf("id %d specified non-existent play deck, ignored",
-			  catch_events[event].id()));
-	  delete q;
-	  return;
-	}
-	delete q;
-	StartPlayout(event);
-	break;
+			  (const char *)catch_config->stationName(),
+			  catch_events[event].channel());
+    q=new RDSqlQuery(sql);
+    if(q->first()) {
+      catch_playout_id[catch_events[event].channel()-129]=id;
+      catch_playout_card[catch_events[event].channel()-129]=
+	q->value(0).toInt();
+      catch_playout_stream[catch_events[event].channel()-129]=
+	q->value(1).toInt();
+      catch_playout_port[catch_events[event].channel()-129]=
+	q->value(2).toInt();
+    }
+    else {
+      LogLine(RDConfig::LogDebug,QString().
+	      sprintf("id %d specified non-existent play deck, ignored",
+		      catch_events[event].id()));
+      delete q;
+      return;
+    }
+    delete q;
+    StartPlayout(event);
+    break;
 
-      case RDRecording::MacroEvent:
-	if(!RDCart::exists(catch_events[event].macroCart())) {
-	  WriteExitCode(event,RDRecording::NoCut);
-	  BroadcastCommand(QString().
-			   sprintf("RE 0 0 %d!",catch_events[event].id()));
-	  LogLine(RDConfig::LogDebug,
-		  QString().sprintf("macro aborted: no such cart: %u, id: %d",
-				    catch_events[event].macroCart(),
-				    catch_events[event].id()));
-	  return;
-	}
-	StartMacroEvent(event);
-	break;
+  case RDRecording::MacroEvent:
+    if(!RDCart::exists(catch_events[event].macroCart())) {
+      WriteExitCode(event,RDRecording::NoCut);
+      BroadcastCommand(QString().
+		       sprintf("RE 0 0 %d!",catch_events[event].id()));
+      LogLine(RDConfig::LogDebug,
+	      QString().sprintf("macro aborted: no such cart: %u, id: %d",
+				catch_events[event].macroCart(),
+				catch_events[event].id()));
+      return;
+    }
+    StartMacroEvent(event);
+    break;
 	
-      case RDRecording::SwitchEvent:
-	StartSwitchEvent(event);
-	break;
+  case RDRecording::SwitchEvent:
+    StartSwitchEvent(event);
+    break;
 
-      case RDRecording::Download:
-	if(!RDCut::exists(catch_events[event].cutName())) {
-	  WriteExitCode(event,RDRecording::NoCut);
-	  BroadcastCommand(QString().
-			   sprintf("RE 0 0 %d!",catch_events[event].id()));
-	  LogLine(RDConfig::LogDebug,QString().
-		  sprintf("download aborted: no such cut: %s, id: %d",
-			  (const char *)catch_events[event].cutName(),
-			  catch_events[event].id()));
-	  return;
-	}
+  case RDRecording::Download:
+    if(!RDCut::exists(catch_events[event].cutName())) {
+      WriteExitCode(event,RDRecording::NoCut);
+      BroadcastCommand(QString().
+		       sprintf("RE 0 0 %d!",catch_events[event].id()));
+      LogLine(RDConfig::LogDebug,QString().
+	      sprintf("download aborted: no such cut: %s, id: %d",
+		      (const char *)catch_events[event].cutName(),
+		      catch_events[event].id()));
+      return;
+    }
 
-	//
-	// Load Import Parameters
-	//
-	sql=QString().sprintf("select DEFAULT_FORMAT,DEFAULT_CHANNELS,\
-                               DEFAULT_SAMPRATE,DEFAULT_LAYER,DEFAULT_BITRATE,\
-                               RIPPER_LEVEL\
+    //
+    // Load Import Parameters
+    //
+    sql=QString().sprintf("select DEFAULT_FORMAT,DEFAULT_CHANNELS,\
+                               DEFAULT_SAMPRATE,DEFAULT_LAYER,DEFAULT_BITRATE, \
+                               RIPPER_LEVEL				\
                                from RDLIBRARY where STATION=\"%s\"",
-			      (const char *)catch_config->stationName());
-	q=new RDSqlQuery(sql);
-	if(q->first())
-	{
-	  catch_default_format=q->value(0).toInt();
-	  catch_default_channels=q->value(1).toInt();
-	  catch_default_samplerate=q->value(2).toInt();
-	  catch_default_layer=q->value(3).toInt();
-	  catch_default_bitrate=q->value(4).toInt();
-	  catch_ripper_level=q->value(5).toInt();
-	}
-	else {
-	  LogLine(RDConfig::LogWarning,
-		  "unable to load import audio configuration");
-	  delete q;
-	  return;
-	}
-	delete q;
-	catch_events[event].
-	  setResolvedUrl(RDDateTimeDecode(catch_events[event].url(),
+			  (const char *)catch_config->stationName());
+    q=new RDSqlQuery(sql);
+    if(q->first())
+      {
+	catch_default_format=q->value(0).toInt();
+	catch_default_channels=q->value(1).toInt();
+	catch_default_samplerate=q->value(2).toInt();
+	catch_default_layer=q->value(3).toInt();
+	catch_default_bitrate=q->value(4).toInt();
+	catch_ripper_level=q->value(5).toInt();
+      }
+    else {
+      LogLine(RDConfig::LogWarning,
+	      "unable to load import audio configuration");
+      delete q;
+      return;
+    }
+    delete q;
+    catch_events[event].
+      setResolvedUrl(RDDateTimeDecode(catch_events[event].url(),
 	       QDateTime(date.addDays(catch_events[event].eventdateOffset()),
-	       current_time)));
+			 current_time),catch_rdstation,RDConfiguration()));
 	StartDownloadEvent(event);
 	break;
 
-      case RDRecording::Upload:
-	if(!RDCut::exists(catch_events[event].cutName())) {
-	  WriteExitCode(event,RDRecording::NoCut);
-	  BroadcastCommand(QString().
-			   sprintf("RE 0 0 %d!",catch_events[event].id()));
-	  LogLine(RDConfig::LogNotice,QString().
-		  sprintf("upload aborted: no such cut: %s, id: %d",
-			  (const char *)catch_events[event].cutName(),
-			  catch_events[event].id()));
-	  return;
-	}
-	StartUploadEvent(event);
-	break;
+  case RDRecording::Upload:
+    if(!RDCut::exists(catch_events[event].cutName())) {
+      WriteExitCode(event,RDRecording::NoCut);
+      BroadcastCommand(QString().
+		       sprintf("RE 0 0 %d!",catch_events[event].id()));
+      LogLine(RDConfig::LogNotice,QString().
+	      sprintf("upload aborted: no such cut: %s, id: %d",
+		      (const char *)catch_events[event].cutName(),
+		      catch_events[event].id()));
+      return;
+    }
+    StartUploadEvent(event);
+    break;
+
+  case RDRecording::LastType:
+    break;
   }
 }
 
@@ -1354,13 +1359,17 @@ bool MainObject::StartRecording(int event)
   bool valid;
   QDateTime datetime=cut->startDatetime(&valid);
   if(valid) {
-    datetime.setDate(QDate::currentDate().
-		     addDays(catch_events[event].startdateOffset()));
-    cut->setStartDatetime(datetime,true);
-    datetime=cut->endDatetime(&valid);
-    datetime.setDate(QDate::currentDate().
-		     addDays(catch_events[event].enddateOffset()));
-    cut->setEndDatetime(datetime,true);
+    if(catch_events[event].startdateOffset()!=0) {
+      datetime.setDate(QDate::currentDate().
+		       addDays(catch_events[event].startdateOffset()));
+      cut->setStartDatetime(datetime,true);
+    }
+    if(catch_events[event].enddateOffset()!=0) {
+      datetime=cut->endDatetime(&valid);
+      datetime.setDate(QDate::currentDate().
+		       addDays(catch_events[event].enddateOffset()));
+      cut->setEndDatetime(datetime,true);
+    }
   }
   delete cut;
 
@@ -1910,7 +1919,7 @@ void MainObject::LoadEngine(bool adv_day)
 				       (const char *)catch_rdstation->name());
   q=new RDSqlQuery(sql);
   while(q->next()) {
-    catch_events.push_back(CatchEvent());
+    catch_events.push_back(CatchEvent(catch_rdstation,RDConfiguration()));
     LoadEvent(q,&catch_events.back(),true);
   }
   LogLine(RDConfig::LogInfo,QString().sprintf("loaded %d events",(int)catch_events.size()));
@@ -2183,45 +2192,48 @@ bool MainObject::AddEvent(int id)
 		      (const char *)catch_rdstation->name(),id);
   q=new RDSqlQuery(sql);
   if(q->first()) {
-    catch_events.push_back(CatchEvent());
+    catch_events.push_back(CatchEvent(catch_rdstation,RDConfiguration()));
     LoadEvent(q,&catch_events.back(),true);
     switch((RDRecording::Type)q->value(2).toInt()) {
-	case RDRecording::Recording:
-	  LogLine(RDConfig::LogNotice,QString().
-		  sprintf("loading event %d, Type: recording, Cut: %s",
-			  id,(const char *)q->value(4).toString()));
-	  break;
+    case RDRecording::Recording:
+      LogLine(RDConfig::LogNotice,QString().
+	      sprintf("loading event %d, Type: recording, Cut: %s",
+		      id,(const char *)q->value(4).toString()));
+      break;
 
-	case RDRecording::Playout:
-	  LogLine(RDConfig::LogNotice,QString().
-		  sprintf("loading event %d, Type: playout, Cut: %s",
-			  id,(const char *)q->value(4).toString()));
-	  break;
+    case RDRecording::Playout:
+      LogLine(RDConfig::LogNotice,QString().
+	      sprintf("loading event %d, Type: playout, Cut: %s",
+		      id,(const char *)q->value(4).toString()));
+      break;
 
-	case RDRecording::MacroEvent:
-	  LogLine(RDConfig::LogNotice,QString().
-		  sprintf("loading event %d, Type: macro, Cart: %d",
-			  id,q->value(23).toUInt()));
-	  break;
+    case RDRecording::MacroEvent:
+      LogLine(RDConfig::LogNotice,QString().
+	      sprintf("loading event %d, Type: macro, Cart: %d",
+		      id,q->value(23).toUInt()));
+      break;
 
-	case RDRecording::SwitchEvent:
-	  LogLine(RDConfig::LogNotice,QString().sprintf(
+    case RDRecording::SwitchEvent:
+      LogLine(RDConfig::LogNotice,QString().sprintf(
 	    "loading event %d, Type: switch, Matrix: %d, Source: %d  Dest: %d",
-			id,q->value(3).toInt(),q->value(24).toInt(),
-			q->value(25).toInt()));
-	  break;
+	    id,q->value(3).toInt(),q->value(24).toInt(),
+	    q->value(25).toInt()));
+      break;
 
-	case RDRecording::Download:
-	  LogLine(RDConfig::LogNotice,QString().
-		  sprintf("loading event %d, Type: download, Cut: %s",
-			  id,(const char *)q->value(4).toString()));
-	  break;
+    case RDRecording::Download:
+      LogLine(RDConfig::LogNotice,QString().
+	      sprintf("loading event %d, Type: download, Cut: %s",
+		      id,(const char *)q->value(4).toString()));
+      break;
 
-	case RDRecording::Upload:
-	  LogLine(RDConfig::LogNotice,QString().
-		  sprintf("loading event %d, Type: upload, Cut: %s",
-			  id,(const char *)q->value(4).toString()));
-	  break;
+    case RDRecording::Upload:
+      LogLine(RDConfig::LogNotice,QString().
+	      sprintf("loading event %d, Type: upload, Cut: %s",
+		      id,(const char *)q->value(4).toString()));
+      break;
+
+    case RDRecording::LastType:
+      break;
     }
     delete q;
     return true;
@@ -2241,47 +2253,49 @@ void MainObject::RemoveEvent(int id)
     return;
   }
   switch(catch_events[event].type()) {
-      case RDRecording::Recording:
-	LogLine(RDConfig::LogDebug,QString().
-		sprintf("removed event %d, Type: recording, Cut: %s",
-			id,(const char *)catch_events[event].cutName()));
-	break;
+  case RDRecording::Recording:
+    LogLine(RDConfig::LogDebug,QString().
+	    sprintf("removed event %d, Type: recording, Cut: %s",
+		    id,(const char *)catch_events[event].cutName()));
+    break;
 	
-      case RDRecording::Playout:
-	LogLine(RDConfig::LogDebug,QString().
-		sprintf("removed event %d, Type: playout, Cut: %s",
-			id,
-			(const char *)catch_events[event].cutName()));
-	break;
+  case RDRecording::Playout:
+    LogLine(RDConfig::LogDebug,QString().
+	    sprintf("removed event %d, Type: playout, Cut: %s",
+		    id,
+		    (const char *)catch_events[event].cutName()));
+    break;
 	
-      case RDRecording::MacroEvent:
-	LogLine(RDConfig::LogDebug,QString().
-		sprintf("removed event %d, Type: macro, Cart: %u",
-			id,
-			catch_events[event].macroCart()));
-	break;
+  case RDRecording::MacroEvent:
+    LogLine(RDConfig::LogDebug,QString().
+	    sprintf("removed event %d, Type: macro, Cart: %u",
+		    id,
+		    catch_events[event].macroCart()));
+    break;
 	
-      case RDRecording::SwitchEvent:
-	LogLine(RDConfig::LogDebug,QString().sprintf(
-	   "removed event %d, Type: switch, Matrix: %d, Source: %d  Dest: %d",
-		  id,
-		  catch_events[event].channel(),
-		  catch_events[event].switchInput(),
-		  catch_events[event].switchOutput()));
-	break;
+  case RDRecording::SwitchEvent:
+    LogLine(RDConfig::LogDebug,QString().sprintf(
+	    "removed event %d, Type: switch, Matrix: %d, Source: %d  Dest: %d",
+	    id,
+	    catch_events[event].channel(),
+	    catch_events[event].switchInput(),
+	    catch_events[event].switchOutput()));
+    break;
 	
-      case RDRecording::Download:
-	LogLine(RDConfig::LogDebug,QString().
-		sprintf("removed event %d, Type: download, Cut: %s",
-			id,(const char *)catch_events[event].cutName()));
-	break;
-	
-      case RDRecording::Upload:
-	LogLine(RDConfig::LogDebug,QString().
-		sprintf("removed event %d, Type: upload, Cut: %s",
-			id,(const char *)catch_events[event].cutName()));
-	break;
+  case RDRecording::Download:
+    LogLine(RDConfig::LogDebug,QString().
+	    sprintf("removed event %d, Type: download, Cut: %s",
+		    id,(const char *)catch_events[event].cutName()));
+    break;
 	
+  case RDRecording::Upload:
+    LogLine(RDConfig::LogDebug,QString().
+	    sprintf("removed event %d, Type: upload, Cut: %s",
+		    id,(const char *)catch_events[event].cutName()));
+    break;
+
+  case RDRecording::LastType:
+    break;
   }
   std::vector<CatchEvent>::iterator it=catch_events.begin()+event;
   catch_events.erase(it,it+1);
@@ -2315,49 +2329,52 @@ void MainObject::PurgeEvent(int event)
   delete q;
   BroadcastCommand(QString().sprintf("PE %d!",catch_events[event].id()));
   switch(catch_events[event].type()) {
-	case RDRecording::Recording:
-	  LogLine(RDConfig::LogDebug,QString().
-		  sprintf("purged event %d, Type: recording, Cut: %s",
-			  catch_events[event].id(),
-			  (const char *)catch_events[event].cutName()));
-	  break;
+  case RDRecording::Recording:
+    LogLine(RDConfig::LogDebug,QString().
+	    sprintf("purged event %d, Type: recording, Cut: %s",
+		    catch_events[event].id(),
+		    (const char *)catch_events[event].cutName()));
+    break;
 
-	case RDRecording::Playout:
-	  LogLine(RDConfig::LogDebug,QString().
-		  sprintf("purged event %d, Type: playout, Cut: %s",
-			  catch_events[event].id(),
-			  (const char *)catch_events[event].cutName()));
-	  break;
+  case RDRecording::Playout:
+    LogLine(RDConfig::LogDebug,QString().
+	    sprintf("purged event %d, Type: playout, Cut: %s",
+		    catch_events[event].id(),
+		    (const char *)catch_events[event].cutName()));
+    break;
 
-	case RDRecording::MacroEvent:
-	  LogLine(RDConfig::LogDebug,QString().
-		  sprintf("purged event %d, Type: macro, Cart: %u",
-			  catch_events[event].id(),
-			  catch_events[event].macroCart()));
-	  break;
+  case RDRecording::MacroEvent:
+    LogLine(RDConfig::LogDebug,QString().
+	    sprintf("purged event %d, Type: macro, Cart: %u",
+		    catch_events[event].id(),
+		    catch_events[event].macroCart()));
+    break;
 
-	case RDRecording::SwitchEvent:
-	  LogLine(RDConfig::LogDebug,QString().sprintf(
+  case RDRecording::SwitchEvent:
+    LogLine(RDConfig::LogDebug,QString().sprintf(
 	    "purged event %d, Type: switch, Matrix: %d, Source: %d  Dest: %d",
 	    catch_events[event].id(),
 	    catch_events[event].channel(),
 	    catch_events[event].switchInput(),
 	    catch_events[event].switchOutput()));
-	  break;
+    break;
 
-	case RDRecording::Download:
-	  LogLine(RDConfig::LogDebug,QString().
-		  sprintf("purged event %d, Type: download, Cut: %s",
-			  catch_events[event].id(),
-			  (const char *)catch_events[event].cutName()));
-	  break;
+  case RDRecording::Download:
+    LogLine(RDConfig::LogDebug,QString().
+	    sprintf("purged event %d, Type: download, Cut: %s",
+		    catch_events[event].id(),
+		    (const char *)catch_events[event].cutName()));
+    break;
 
-	case RDRecording::Upload:
-	  LogLine(RDConfig::LogDebug,QString().
-		  sprintf("purged event %d, Type: upload, Cut: %s",
-			  catch_events[event].id(),
-			  (const char *)catch_events[event].cutName()));
-	  break;
+  case RDRecording::Upload:
+    LogLine(RDConfig::LogDebug,QString().
+	    sprintf("purged event %d, Type: upload, Cut: %s",
+		    catch_events[event].id(),
+		    (const char *)catch_events[event].cutName()));
+    break;
+
+  case RDRecording::LastType:
+    break;
   }
   catch_engine->removeEvent(catch_events[event].id());
   std::vector<CatchEvent>::iterator it=catch_events.begin()+event;
@@ -2394,7 +2411,8 @@ void MainObject::CheckInRecording(QString cutname,CatchEvent *evt,
   s->setSampleRate(evt->sampleRate());
   s->setBitRate(evt->bitrate());
   s->setChannels(evt->channels());
-  cut->checkInRecording(catch_config->stationName(),s,msecs);
+  cut->checkInRecording(catch_config->stationName(),"",
+			catch_config->stationName(),s,msecs);
   cut->setSha1Hash(RDSha1Hash(RDCut::pathName(cut->cutName())));
   delete s;
   cut->autoTrim(RDCut::AudioBoth,-threshold);
@@ -2614,139 +2632,48 @@ void MainObject::ResolveErrorWildcards(CatchEvent *event,
   rml->replace("%t",event->startTime().toString("hh:mm:ss"));
   rml->replace("%y",RDRecording::typeString(event->type()));
   switch(event->type()) {
-      case RDRecording::Recording:
-	rml->replace("%k",QString().sprintf("%d",event->channel()));
-	rml->replace("%n",event->cutName().left(6));
-	rml->replace("%u","n/a");
-	break;
+  case RDRecording::Recording:
+    rml->replace("%k",QString().sprintf("%d",event->channel()));
+    rml->replace("%n",event->cutName().left(6));
+    rml->replace("%u","n/a");
+    break;
 
-      case RDRecording::Playout:
-	rml->replace("%k",QString().sprintf("%d",event->channel()-128));
-	rml->replace("%n",event->cutName().left(6));
-	rml->replace("%u","n/a");
-	break;
+  case RDRecording::Playout:
+    rml->replace("%k",QString().sprintf("%d",event->channel()-128));
+    rml->replace("%n",event->cutName().left(6));
+    rml->replace("%u","n/a");
+    break;
 
-      case RDRecording::Upload:
-	rml->replace("%k","n/a");
-	rml->replace("%n",event->cutName().left(6));
-	rml->replace("%u",event->resolvedUrl());
-	break;
+  case RDRecording::Upload:
+    rml->replace("%k","n/a");
+    rml->replace("%n",event->cutName().left(6));
+    rml->replace("%u",event->resolvedUrl());
+    break;
 
-      case RDRecording::Download:
-	rml->replace("%k","n/a");
-	rml->replace("%n",event->cutName().left(6));
-	rml->replace("%u",event->resolvedUrl());
-	break;
+  case RDRecording::Download:
+    rml->replace("%k","n/a");
+    rml->replace("%n",event->cutName().left(6));
+    rml->replace("%u",event->resolvedUrl());
+    break;
 
-      case RDRecording::MacroEvent:
-	rml->replace("%k","n/a");
-	rml->replace("%n",QString().sprintf("%06u",event->macroCart()));
-	rml->replace("%u","n/a");
-	break;
+  case RDRecording::MacroEvent:
+    rml->replace("%k","n/a");
+    rml->replace("%n",QString().sprintf("%06u",event->macroCart()));
+    rml->replace("%u","n/a");
+    break;
 
-      case RDRecording::SwitchEvent:
-	rml->replace("%k","n/a");
-	rml->replace("%n",tr("n/a"));
-	rml->replace("%u","n/a");
-	break;
+  case RDRecording::SwitchEvent:
+    rml->replace("%k","n/a");
+    rml->replace("%n",tr("n/a"));
+    rml->replace("%u","n/a");
+    break;
+
+  case RDRecording::LastType:
+    break;
   }
 }
 
 
-void MainObject::StartDropboxes()
-{
-  QString sql;
-  RDSqlQuery *q;
-  RDSqlQuery *q1;
-
-  //
-  // Kill Old Instances
-  //
-  system("killall rdimport");
-
-  //
-  // Launch Dropbox Configurations
-  //
-  sql=QString("select ID,GROUP_NAME,PATH,NORMALIZATION_LEVEL,")+
-    "AUTOTRIM_LEVEL,TO_CART,USE_CARTCHUNK_ID,TITLE_FROM_CARTCHUNK_ID,"+
-    "DELETE_CUTS,METADATA_PATTERN,FIX_BROKEN_FORMATS,LOG_PATH,"+
-    "DELETE_SOURCE,STARTDATE_OFFSET,ENDDATE_OFFSET,ID,"+
-    "IMPORT_CREATE_DATES,CREATE_STARTDATE_OFFSET,"+
-    "CREATE_ENDDATE_OFFSET,SET_USER_DEFINED "+
-    "from DROPBOXES where STATION_NAME=\""+
-    RDEscapeString(catch_config->stationName())+"\"";
-  q=new RDSqlQuery(sql);
-  while(q->next()) {
-    QString cmd=QString().
-      sprintf("nice rdimport --persistent-dropbox-id=%d --drop-box --log-mode",
-	      q->value(15).toInt());
-    sql=QString("select SCHED_CODE from DROPBOX_SCHED_CODES where ")+
-      QString().sprintf("DROPBOX_ID=%d",q->value(0).toInt());
-    q1=new RDSqlQuery(sql);
-    while(q1->next()) {
-      cmd+=QString(" --add-scheduler-code=\"")+q1->value(0).toString()+"\"";
-    }
-    delete q1;
-    cmd+=
-      QString().sprintf(" --normalization-level=%d",q->value(3).toInt()/100);
-    cmd+=
-      QString().sprintf(" --autotrim-level=%d",q->value(4).toInt()/100);
-    if(q->value(5).toUInt()>0) {
-      cmd+=QString().sprintf(" --to-cart=%u",q->value(5).toUInt());
-    }
-    if(q->value(6).toString()=="Y") {
-      cmd+=" --use-cartchunk-cutid";
-    }
-    if(q->value(7).toString()=="Y") {
-      cmd+=" --title-from-cartchunk-cutid";
-    }
-    if(q->value(8).toString()=="Y") {
-      cmd+=" --delete-cuts";
-    }
-    if(!q->value(9).toString().isEmpty()) {
-      cmd+=QString().sprintf(" \"--metadata-pattern=%s\"",
-			     (const char *)q->value(9).toString());
-    }
-    if(q->value(10).toString()=="Y") {
-      cmd+=" --fix-broken-formats";
-    }
-    if(q->value(12).toString()=="Y") {
-      cmd+=" --delete-source";
-    }
-    if(q->value(16).toString()=="Y") {
-      cmd+=QString().sprintf(" --create-startdate-offset=%d",
-			     q->value(17).toInt());
-      cmd+=QString().sprintf(" --create-enddate-offset=%d",
-			     q->value(18).toInt());
-    }
-    if(!q->value(19).toString().isEmpty()) {
-      cmd+=" --set-user-defined="+RDEscapeString(q->value(19).toString());
-    }
-    cmd+=QString().sprintf(" --startdate-offset=%d",q->value(13).toInt());
-    cmd+=QString().sprintf(" --enddate-offset=%d",q->value(14).toInt());
-    cmd+=QString().sprintf(" %s \"%s\"",(const char *)q->value(1).toString(),
-			   (const char *)q->value(2).toString());
-    if(!q->value(11).toString().isEmpty()) {
-      cmd+=QString().sprintf(" >> %s 2>> %s",
-			     (const char *)q->value(11).toString(),
-			     (const char *)q->value(11).toString());
-    }
-    else {
-      cmd+=" > /dev/null 2> /dev/null";
-    }
-    cmd+=" &";
-    LogLine(RDConfig::LogInfo,QString().
-	    sprintf("launching dropbox configuration: \"%s\"",
-		    (const char *)cmd));
-    if(fork()==0) {
-      system(cmd);
-      exit(0);
-    }
-  }
-  delete q;
-}
-
-
 unsigned MainObject::GetNextDynamicId()
 {
   unsigned id=RDCATCHD_DYNAMIC_BASE_ID;
@@ -2777,7 +2704,7 @@ void MainObject::StartRmlRecording(int chan,int cartnum,int cutnum,int maxlen)
   RDDeck *deck=new RDDeck(catch_config->stationName(),chan);
   RDCut *cut=new RDCut(cartnum,cutnum);
   QDateTime dt=QDateTime(QDate::currentDate(),QTime::currentTime());
-  catch_events.push_back(CatchEvent());
+  catch_events.push_back(CatchEvent(catch_rdstation,RDConfiguration()));
   catch_events.back().setId(GetNextDynamicId());
   catch_events.back().setIsActive(true);
   catch_events.back().setOneShot(true);
