@@ -2,9 +2,7 @@
 //
 // List and Generate RDLibrary Reports
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: list_reports.h,v 1.6 2011/10/27 15:23:26 cvs Exp $
+//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,6 +23,8 @@
 
 #include <qdialog.h>
 #include <qcombobox.h>
+#include <qcheckbox.h>
+#include <qlabel.h>
 #include <qsqldatabase.h>
 
 #include <rdsvc.h>
@@ -35,21 +35,25 @@ class ListReports : public QDialog
  Q_OBJECT
  public:
  ListReports(const QString &filter,const QString &type_filter,
-	     const QString &group,const QString &schedcode,
-	     QWidget *parent=0,const char *name=0);
+	     const QString &group,const QString &schedcode,QWidget *parent=0);
  ~ListReports();
  QSize sizeHint() const;
  QSizePolicy sizePolicy() const;
  
  private slots:
+  void typeActivatedData(int index);
   void generateData();
   void closeData();
 
  private:
   void GenerateCartReport(QString *report);
   void GenerateCutReport(QString *report);
-  void GenerateCartDump(QString *report);
+  void GenerateCartDumpFixed(QString *report,bool prepend_names);
+  void GenerateCartDumpCsv(QString *report,bool prepend_names);
+  QLabel *list_reports_label;
   QComboBox *list_reports_box;
+  QCheckBox *list_fieldnames_check;
+  QLabel *list_fieldnames_label;
   QString list_filter;
   QString list_type_filter;
   QString list_group;
