@@ -43,7 +43,7 @@
     </message>
     <message>
         <source>ORIGIN</source>
-        <translation>OPPHAV</translation>
+        <translation type="obsolete">OPPHAV</translation>
     </message>
     <message>
         <source>OUTCUE</source>
@@ -71,7 +71,7 @@
     </message>
     <message>
         <source>Cuts</source>
-        <translation>Kutt</translation>
+        <translation type="obsolete">Kutt</translation>
     </message>
     <message>
         <source>Cut Info</source>
@@ -119,7 +119,7 @@ markørar</translation>
     <message>
         <source>This cut is used in one or more RDCatch events!
 Do you still want to delete it?</source>
-        <translation>Dette kuttet er brukt i ei eller fleire RDCatch-hendingar.
+        <translation type="obsolete">Dette kuttet er brukt i ei eller fleire RDCatch-hendingar.
 Er du sikker på at du vil sletta det?</translation>
     </message>
     <message>
@@ -164,7 +164,80 @@ Vil du halda fram?</translation>
     </message>
     <message>
         <source>1 Cut</source>
-        <translation>1 kutt</translation>
+        <translation type="obsolete">1 kutt</translation>
+    </message>
+    <message>
+        <source>RDLibrary</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No audio is present in the cut!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This cart cannot contain any additional cuts!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RDLibrary - Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete Cuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>One or more cuts are used in one or more RDCatch events!
+Do you still want to delete?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to delete audio for cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No data copied - you must select a single cut!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Paste Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You must select a single cut!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ORD</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>not available</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>INGEST</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SOURCE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -257,15 +330,15 @@ Vil du halda fram?</translation>
     </message>
     <message>
         <source>No Access</source>
-        <translation>Ingen tilgang</translation>
+        <translation type="obsolete">Ingen tilgang</translation>
     </message>
     <message>
         <source>Unable to open the file for writing!</source>
-        <translation>Greidde ikkje skriva til fila!</translation>
+        <translation type="obsolete">Greidde ikkje skriva til fila!</translation>
     </message>
     <message>
         <source>OK</source>
-        <translation>OK</translation>
+        <translation type="obsolete">OK</translation>
     </message>
     <message>
         <source>Audio Track</source>
@@ -277,30 +350,63 @@ Vil du halda fram?</translation>
     </message>
     <message>
         <source>Rip Complete</source>
-        <translation>Ferdig å rippa</translation>
+        <translation type="unfinished">Ferdig å rippa</translation>
     </message>
     <message>
         <source>Rip complete!</source>
-        <translation>Ferdig å rippa!</translation>
+        <translation type="unfinished">Ferdig å rippa!</translation>
     </message>
     <message>
         <source>Rip Aborted</source>
-        <translation>Avbraut rippinga</translation>
+        <translation type="obsolete">Avbraut rippinga</translation>
     </message>
     <message>
         <source>The rip has been aborted.</source>
-        <translation>Rippinga er avbroten.</translation>
+        <translation type="obsolete">Rippinga er avbroten.</translation>
     </message>
     <message>
         <source>Rip Failed</source>
-        <translation>Rippinga mislukka</translation>
+        <translation type="obsolete">Rippinga mislukka</translation>
     </message>
     <message>
         <source>The ripper encountered an error.
 Please check your ripper configuration and try again.</source>
-        <translation>Rippinga vart mislukka.
+        <translation type="obsolete">Rippinga vart mislukka.
 Sjå over innstillingane for ripping, og prøv ein gong til.</translation>
     </message>
+    <message>
+        <source>RDLibrary - Importer Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RDLibrary - Ripper Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Abort
+Rip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rip Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[none]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ripper Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to create temporary directory!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DiskRipper</name>
@@ -363,13 +469,13 @@ Sjå over innstillingane for ripping, og prøv ein gong til.</translation>
     <message>
         <source>Set
 &amp;Cut</source>
-        <translation>Set
+        <translation type="obsolete">Set
 &amp;Kutt</translation>
     </message>
     <message>
         <source>Set All
 &amp;New Carts</source>
-        <translation>Set alle
+        <translation type="obsolete">Set alle
 &amp;Nye korger</translation>
     </message>
     <message>
@@ -432,11 +538,11 @@ Vil du halda fram?</translation>
     </message>
     <message>
         <source>Library Error</source>
-        <translation>Bibliotekfeil</translation>
+        <translation type="obsolete">Bibliotekfeil</translation>
     </message>
     <message>
         <source>Insufficient free carts available in group!</source>
-        <translation>Det er ikkje nok ledige korger i gruppa!</translation>
+        <translation type="obsolete">Det er ikkje nok ledige korger i gruppa!</translation>
     </message>
     <message>
         <source>Audio Track</source>
@@ -456,43 +562,118 @@ Vil du halda fram?</translation>
     </message>
     <message>
         <source>Rip Aborted</source>
-        <translation>Avbraut rippinga</translation>
+        <translation type="obsolete">Avbraut rippinga</translation>
     </message>
     <message>
         <source>The rip has been aborted.</source>
-        <translation>Rippinga er avbroten.</translation>
+        <translation type="obsolete">Rippinga er avbroten.</translation>
     </message>
     <message>
         <source>Rip Failed</source>
-        <translation>Rippinga mislukka</translation>
+        <translation type="obsolete">Rippinga mislukka</translation>
     </message>
     <message>
         <source>The ripper encountered an error.
 Please check your ripper configuration and try again.</source>
-        <translation>Rippinga vart mislukka.
+        <translation type="obsolete">Rippinga vart mislukka.
 Sjå over innstillingane for ripping, og prøv ein gong til.</translation>
     </message>
     <message>
         <source>Total Progress</source>
-        <translation>Framgang totalt</translation>
+        <translation type="unfinished">Framgang totalt</translation>
     </message>
     <message>
         <source>No Access</source>
-        <translation>Ingen tilgang</translation>
+        <translation type="obsolete">Ingen tilgang</translation>
     </message>
     <message>
         <source>Unable to open the file for writing!</source>
-        <translation>Greidde ikkje skriva til fila!</translation>
+        <translation type="obsolete">Greidde ikkje skriva til fila!</translation>
     </message>
     <message>
         <source>OK</source>
-        <translation>OK</translation>
+        <translation type="obsolete">OK</translation>
     </message>
     <message>
         <source>&amp;Rip
 Disc</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>RDLibrary - Importer Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RDLibrary - Ripper Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Abort
+Rip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rip
+Disk</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rip aborted!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ripper Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to create temporary directory!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add Cart
+Per Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add Single
+Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set
+&amp;Cart/Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[continued]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Modify
+Cart Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear
+Selection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to allocate carts in group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to allocate cart in group</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditCart</name>
@@ -582,7 +763,7 @@ Disc</source>
     </message>
     <message>
         <source>Schedule Cuts:</source>
-        <translation>Planlegg kutt:</translation>
+        <translation type="obsolete">Planlegg kutt:</translation>
     </message>
     <message>
         <source>Execute Asynchronously</source>
@@ -620,11 +801,11 @@ skript</translation>
     </message>
     <message>
         <source>Sequentially</source>
-        <translation>I rekkjefylgje</translation>
+        <translation type="obsolete">I rekkjefylgje</translation>
     </message>
     <message>
         <source>Randomly</source>
-        <translation>Tilfeldig</translation>
+        <translation type="obsolete">Tilfeldig</translation>
     </message>
     <message>
         <source></source>
@@ -661,6 +842,54 @@ Notes</source>
         <source>The cart title must be unique!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>RDLibrary - Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This cart cannot contain any additional cuts!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cond&amp;uctor:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Song &amp;ID:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Beats per Minute:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use Event Length for Now &amp;&amp; Next Updates</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>By Specified Order</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>By Weight</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Schedule Cuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The following cut order values are assigned more than once</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Duplicate Cut Order</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditMacro</name>
@@ -677,6 +906,52 @@ Notes</source>
         <translation>&amp;Avbryt</translation>
     </message>
 </context>
+<context>
+    <name>EditNotes</name>
+    <message>
+        <source>Notes for cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished">&amp;OK</translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">&amp;Avbryt</translation>
+    </message>
+</context>
+<context>
+    <name>EditSchedulerCodes</name>
+    <message>
+        <source>Select Scheduler Codes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Available Codes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Assigned Codes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ASSIGN to Carts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>REMOVE from Carts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished">&amp;OK</translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">&amp;Avbryt</translation>
+    </message>
+</context>
 <context>
     <name>Filter</name>
     <message>
@@ -700,6 +975,49 @@ Notes</source>
         <translation>&amp;Filter:</translation>
     </message>
 </context>
+<context>
+    <name>ListReports</name>
+    <message>
+        <source>RDLibrary Reports</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart Report</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut Report</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Type:</source>
+        <translation type="unfinished">Type:</translation>
+    </message>
+    <message>
+        <source>&amp;Generate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Close</source>
+        <translation type="unfinished">&amp;Lukk</translation>
+    </message>
+    <message>
+        <source>ALL</source>
+        <translation type="unfinished">ALT</translation>
+    </message>
+    <message>
+        <source>Cart Data Dump (fixed width)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart Data Dump (CSV)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Prepend Field Names</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>MacroCart</name>
     <message>
@@ -843,7 +1161,7 @@ korg</translation>
     </message>
     <message>
         <source>PLAY ORDER</source>
-        <translation>SPELEREKKJEFYLGJE</translation>
+        <translation type="obsolete">SPELEREKKJEFYLGJE</translation>
     </message>
     <message>
         <source>ENFORCE LENGTH</source>
@@ -925,11 +1243,11 @@ Vil du sletta ho likevel?</translation>
     </message>
     <message>
         <source>Sequence</source>
-        <translation>Rekkjefylgje</translation>
+        <translation type="obsolete">Rekkjefylgje</translation>
     </message>
     <message>
         <source>Random</source>
-        <translation>Tilfeldig</translation>
+        <translation type="obsolete">Tilfeldig</translation>
     </message>
     <message>
         <source>TFN</source>
@@ -937,16 +1255,72 @@ Vil du sletta ho likevel?</translation>
     </message>
     <message>
         <source>RDLibrary - Host:</source>
-        <translation>RDLibrary -- Vert:</translation>
+        <translation type="obsolete">RDLibrary -- Vert:</translation>
     </message>
     <message>
         <source>, User:</source>
-        <translation>, brukar:</translation>
+        <translation type="obsolete">, brukar:</translation>
     </message>
     <message>
         <source>Show Note Bubbles</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>RDLibrary</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to delete audio!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Only First </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> Matches</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>COMPOSER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CONDUCTOR</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PUBLISHER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow Cart Dragging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command-line option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ALBUM</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LABEL</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RecordCut</name>
@@ -964,7 +1338,7 @@ Vil du sletta ho likevel?</translation>
     </message>
     <message>
         <source>Origin</source>
-        <translation>Opphav</translation>
+        <translation type="obsolete">Opphav</translation>
     </message>
     <message>
         <source>ISRC</source>
@@ -1060,7 +1434,7 @@ Vil du sletta ho likevel?</translation>
     </message>
     <message>
         <source>NO SYNC!</source>
-        <translation>INGEN SYNK!</translation>
+        <translation type="obsolete">INGEN SYNK!</translation>
     </message>
     <message>
         <source>Channels</source>
@@ -1176,5 +1550,29 @@ Vil du lagra likevel?</translation>
         <source>Unable to connect to Core AudioEngine</source>
         <translation>Greier ikkje kopla til CoreAudioEnginge</translation>
     </message>
+    <message>
+        <source>&amp;ISCI Code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>AES ALARM</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Order</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ingest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
