@@ -2,7 +2,7 @@
 //
 // A Database Check/Repair Tool for Rivendell.
 //
-//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2006,2016-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -357,7 +357,8 @@ void MainObject::CheckClocks()
 	     (const char *)q->value(0).toString());
       fflush(NULL);
       if(UserResponse()) {
-	sql=RDCreateClockTableSql(RDClock::tableName(q->value(0).toString()));
+	sql=RDCreateClockTableSql(RDClock::tableName(q->value(0).toString()),
+				  rdconfig);
 	q2=new QSqlQuery(sql);
 	delete q2;
       }
@@ -392,7 +393,7 @@ void MainObject::CheckEvents()
 	     (const char *)q->value(0).toString());
       fflush(NULL);
       if(UserResponse()) {
-	sql=RDCreateLogTableSql(eventname+"_PRE");
+	sql=RDCreateLogTableSql(eventname+"_PRE",rdconfig);
 	q2=new QSqlQuery(sql);
 	delete q2;
       }
@@ -409,7 +410,7 @@ void MainObject::CheckEvents()
 	     (const char *)q->value(0).toString());
       fflush(NULL);
       if(UserResponse()) {
-	sql=RDCreateLogTableSql(eventname+"_POST");
+	sql=RDCreateLogTableSql(eventname+"_POST",rdconfig);
 	q2=new QSqlQuery(sql);
 	delete q2;
       }
