@@ -2,7 +2,7 @@
 //
 // Rivendell web service portal -- Export service
 //
-//   (C) Copyright 2010-2015 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2010-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,14 +24,15 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#include <rdformpost.h>
-#include <rdweb.h>
-#include <rdcart.h>
 #include <rdaudioconvert.h>
-#include <rdsettings.h>
+#include <rdcart.h>
 #include <rdconf.h>
+#include <rdformpost.h>
+#include <rdsettings.h>
+#include <rdtempdirectory.h>
+#include <rdweb.h>
 
-#include <rdxport.h>
+#include "rdxport.h"
 
 void Xport::Export()
 {
@@ -43,60 +44,60 @@ void Xport::Export()
   //
   int cartnum=0;
   if(!xport_post->getValue("CART_NUMBER",&cartnum)) {
-    XmlExit("Missing CART_NUMBER",400);
+    XmlExit("Missing CART_NUMBER",400,"export.cpp",LINE_NUMBER);
   }
   int cutnum=0;
   if(!xport_post->getValue("CUT_NUMBER",&cutnum)) {
-    XmlExit("Missing CUT_NUMBER",400);
+    XmlExit("Missing CUT_NUMBER",400,"export.cpp",LINE_NUMBER);
   }
   int format=0;
   if(!xport_post->getValue("FORMAT",&format)) {
-    XmlExit("Missing FORMAT",400);
+    XmlExit("Missing FORMAT",400,"export.cpp",LINE_NUMBER);
   }
   int channels=0;
   if(!xport_post->getValue("CHANNELS",&channels)) {
-    XmlExit("Missing CHANNELS",400);
+    XmlExit("Missing CHANNELS",400,"export.cpp",LINE_NUMBER);
   }
   int sample_rate=0;
   if(!xport_post->getValue("SAMPLE_RATE",&sample_rate)) {
-    XmlExit("Missing SAMPLE_RATE",400);
+    XmlExit("Missing SAMPLE_RATE",400,"export.cpp",LINE_NUMBER);
   }
   int bit_rate=0;
   if(!xport_post->getValue("BIT_RATE",&bit_rate)) {
-    XmlExit("Missing BIT_RATE",400);
+    XmlExit("Missing BIT_RATE",400,"export.cpp",LINE_NUMBER);
   }
   int quality=0;
   if(!xport_post->getValue("QUALITY",&quality)) {
-    XmlExit("Missing QUALITY",400);
+    XmlExit("Missing QUALITY",400,"export.cpp",LINE_NUMBER);
   }
   int start_point=-1;
   if(!xport_post->getValue("START_POINT",&start_point)) {
-    XmlExit("Missing START_POINT",400);
+    XmlExit("Missing START_POINT",400,"export.cpp",LINE_NUMBER);
   }
   int end_point=-1;
   if(!xport_post->getValue("END_POINT",&end_point)) {
-    XmlExit("Missing END_POINT",400);
+    XmlExit("Missing END_POINT",400,"export.cpp",LINE_NUMBER);
   }
   int normalization_level=0;
   if(!xport_post->getValue("NORMALIZATION_LEVEL",&normalization_level)) {
-    XmlExit("Missing NORMALIZATION_LEVEL",400);
+    XmlExit("Missing NORMALIZATION_LEVEL",400,"export.cpp",LINE_NUMBER);
   }
   int enable_metadata=false;
   if(!xport_post->getValue("ENABLE_METADATA",&enable_metadata)) {
-    XmlExit("Missing ENABLE_METADATA",400);
+    XmlExit("Missing ENABLE_METADATA",400,"export.cpp",LINE_NUMBER);
   }
   if(!RDCart::exists(cartnum)) {
-    XmlExit("No such cart",404);
+    XmlExit("No such cart",404,"export.cpp",LINE_NUMBER);
   }
   if(!RDCut::exists(cartnum,cutnum)) {
-    XmlExit("No such cut",404);
+    XmlExit("No such cut",404,"export.cpp",LINE_NUMBER);
   }
 
   //
   // Verify User Perms
   //
   if(!xport_user->cartAuthorized(cartnum)) {
-    XmlExit("No such cart",404);
+    XmlExit("No such cart",404,"export.cpp",LINE_NUMBER);
   }
 
   //
@@ -138,8 +139,12 @@ void Xport::Export()
   int fd;
   ssize_t n;
   uint8_t data[2048];
-  QString tmpdir=RDTempDir();
-  QString tmpfile=tmpdir+"/exported_audio";
+  QString err_msg;
+  RDTempDirectory *tempdir=new RDTempDirectory("rdxport-export");
+  if(!tempdir->create(&err_msg)) {
+    XmlExit("unable to create temporary directory ["+err_msg+"]",500);
+  }
+  QString tmpfile=tempdir->path()+"/exported_audio";
   RDAudioConvert *conv=new RDAudioConvert(xport_config->stationName());
   conv->setSourceFile(RDCut::pathName(cartnum,cutnum));
   conv->setDestinationFile(tmpfile);
@@ -179,7 +184,8 @@ void Xport::Export()
     }
     close(fd);
     unlink(tmpfile);
-    rmdir(tmpdir);
+    //    rmdir(tmpdir);
+    delete tempdir;
     Exit(0);
     break;
 
@@ -189,7 +195,7 @@ void Xport::Export()
     break;
 
   case RDAudioConvert::ErrorNoSource:
-    resp_code=403;
+    resp_code=404;
     break;
 
   case RDAudioConvert::ErrorNoDestination:
@@ -208,12 +214,12 @@ void Xport::Export()
   if(wavedata!=NULL) {
     delete wavedata;
   }
-  unlink(tmpfile);
-  rmdir(tmpdir);
+  delete tempdir;
   if(resp_code==200) {
     Exit(200);
   }
   else {
-    XmlExit(RDAudioConvert::errorText(conv_err),resp_code,conv_err);
+    XmlExit(RDAudioConvert::errorText(conv_err),resp_code,"export.cpp",
+	    LINE_NUMBER,conv_err);
   }
 }
